@@ -19,7 +19,8 @@ theme_sovacool <- function() {
     ggplot2::theme(
       legend.margin = ggplot2::margin(0, 0, 0, 0, unit = "pt"),
       legend.box.margin = ggplot2::margin(0, 0, 0, 0, unit = "pt"),
-      plot.margin = ggplot2::margin(0, 0, 0, 0, unit = "pt")
+      plot.margin = ggplot2::margin(0, 0, 0, 0, unit = "pt"),
+      plot.caption = ggplot2::element_text(hjust = 0)
     )
   ))
 }
